@@ -10,11 +10,48 @@ from pollination_streamlit.interactors import ApiClient
 
 from .components_callbacks import register_callback
 
-# get_host
-parent_dir = os.path.dirname(os.path.abspath(__file__))
-build_dir = os.path.join(parent_dir, "./get_host/frontend/build")
-_get_host = _components.declare_component("get_host", path=build_dir)
+_RELEASE = True
 
+if not _RELEASE:
+    _get_host = _components.declare_component("get_host", url="http://localhost:3000")
+    _manage_settings = _components.declare_component("manage_settings", url="http://localhost:3000")
+    _get_geometry = _components.declare_component("get_geometry", url="http://localhost:3000")
+    _recipe_inputs_form = _components.declare_component("recipe_inputs_form", url="http://localhost:3000")
+    _get_hbjson = _components.declare_component("get_hbjson", url="http://localhost:3000")
+    _run_card = _components.declare_component("run_card", url="http://localhost:3000")
+    _study_card = _components.declare_component("study_card", url="http://localhost:3000")
+    _send_geometry = _components.declare_component("send_geometry", url="http://localhost:3000")
+    _create_study = _components.declare_component("create_study", url="http://localhost:3000")
+    _send_hbjson = _components.declare_component("send_hbjson", url="http://localhost:3000")
+    _auth_user = _components.declare_component("auth_user", url="http://localhost:3000")
+    _send_results = _components.declare_component("send_results", url="http://localhost:3000")
+    _select_account = _components.declare_component("select_account", url="http://localhost:3000")
+    _select_run = _components.declare_component("select_run", url="http://localhost:3000")
+    _select_study = _components.declare_component( "select_study", url="http://localhost:3000")
+    _select_recipe = _components.declare_component("select_recipe", url="http://localhost:3000")
+    _select_project = _components.declare_component("select_project", url="http://localhost:3000")
+    _select_cloud_artifact = _components.declare_component("select_cloud_artifact", url="http://localhost:3000")
+else :
+    parent_dir = os.path.dirname(os.path.abspath(__file__))
+    build_dir = os.path.join(parent_dir, "./components/frontend/build")
+    _get_host = _components.declare_component("get_host", path=build_dir)
+    _manage_settings = _components.declare_component("manage_settings", path=build_dir)
+    _get_geometry = _components.declare_component("get_geometry", path=build_dir)
+    _recipe_inputs_form = _components.declare_component("recipe_inputs_form", path=build_dir)
+    _get_hbjson = _components.declare_component("get_hbjson", path=build_dir)
+    _run_card = _components.declare_component("run_card", path=build_dir)
+    _study_card = _components.declare_component("study_card", path=build_dir)
+    _send_geometry = _components.declare_component("send_geometry", path=build_dir)
+    _create_study = _components.declare_component("create_study", path=build_dir)
+    _send_hbjson = _components.declare_component("send_hbjson", path=build_dir)
+    _auth_user = _components.declare_component("auth_user", path=build_dir)
+    _send_results = _components.declare_component("send_results", path=build_dir)
+    _select_account = _components.declare_component("select_account", path=build_dir)
+    _select_run = _components.declare_component("select_run", path=build_dir)
+    _select_study = _components.declare_component( "select_study", path=build_dir)
+    _select_recipe = _components.declare_component("select_recipe", path=build_dir)
+    _select_project = _components.declare_component("select_project", path=build_dir)
+    _select_cloud_artifact = _components.declare_component("select_cloud_artifact", path=build_dir)
 
 def get_host(key='foo'):
     """Create a new instance of "get_host".
@@ -31,17 +68,14 @@ def get_host(key='foo'):
     host: 'web' | 'rhino' | 'revit' | 'sketchup'
     """
 
-    get_host = _get_host(key=key)
+    get_host = _get_host(
+      component='get_host',
+      key=key
+    )
 
     return get_host
 
 
-# get_host
-parent_dir = os.path.dirname(os.path.abspath(__file__))
-build_dir = os.path.join(parent_dir, "./manage_settings/frontend/build")
-_manage_settings = _components.declare_component("manage_settings", path=build_dir)
-
-
 def manage_settings(key='foo', *, settings):
     """Create a new instance of "get_host".
 
@@ -54,8 +88,14 @@ def manage_settings(key='foo', *, settings):
     settings: dict
         A dictionary with the following structure
         
-        {
-            "earth_anchor": {"lat": float, "lon": float},
+        { 
+            "location":{
+                        "city": string,
+                        "latitude": float,
+                        "longitude": float,
+                        "time_zone": float,
+                        "elevation": integer
+                        },
             "units": 'Meters' | 'Millimeters' | 'Feet' | 'Inches' | 'Centimeters',
             "layers": string[],
             "tolerance": float,
@@ -67,26 +107,29 @@ def manage_settings(key='foo', *, settings):
     settings: 
         A dictionary with the following structure
 
-        {
-            "earth_anchor": {"lat": float, "lon": float},
-            "units": integer,
+        { 
+            "location":{
+                        "city": string,
+                        "latitude": float,
+                        "longitude": float,
+                        "time_zone": float,
+                        "elevation": integer
+                        },
+            "units": 'Meters' | 'Millimeters' | 'Feet' | 'Inches' | 'Centimeters',
             "layers": string[],
             "tolerance": float,
             "angle_tolerance": float
         }
     """
 
-    manage_settings = _manage_settings(key=key, settings=settings)
+    manage_settings = _manage_settings(
+      component='manage_settings',
+      key=key, 
+      settings=settings
+    )
 
     return manage_settings
 
-
-# get_geometry
-parent_dir = os.path.dirname(os.path.abspath(__file__))
-build_dir = os.path.join(parent_dir, "./get_geometry/frontend/build")
-_get_geometry = _components.declare_component("get_geometry", path=build_dir)
-
-
 def get_geometry(
     key: str = 'foo', *, 
     label: str = None, 
@@ -147,17 +190,15 @@ def get_geometry(
         kwargs = kwargs or {}
         register_callback(key, on_change, *args, **kwargs)
 
-    get_geometry = _get_geometry(key=key, button_label=label, options_config=options)
+    get_geometry = _get_geometry(
+      component='get_geometry',
+      key=key, 
+      button_label=label, 
+      options_config=options
+    )
 
     return get_geometry
 
-
-# get_hbjson
-parent_dir = os.path.dirname(os.path.abspath(__file__))
-build_dir = os.path.join(parent_dir, "./get_hbjson/frontend/build")
-_get_hbjson = _components.declare_component("get_hbjson", path=build_dir)
-
-
 def get_hbjson(
     key: str = 'foo', *,
     label: str = None,
@@ -218,23 +259,22 @@ def get_hbjson(
         kwargs = kwargs or {}
         register_callback(key, on_change, *args, **kwargs)
 
-    get_hbjson = _get_hbjson(key=key, button_label=label, options_config=options)
+    get_hbjson = _get_hbjson(
+      component='get_hbjson',
+      key=key, 
+      button_label=label, 
+      options_config=options
+    )
 
     return get_hbjson
 
-
-# send_geometry
-parent_dir = os.path.dirname(os.path.abspath(__file__))
-build_dir = os.path.join(parent_dir, "./send_geometry/frontend/build")
-_send_geometry = _components.declare_component("send_geometry", path=build_dir)
-
-
 def send_geometry(
     key='foo', *, 
     geometry={}, 
     label: str = None, 
     option='preview', 
-    options: dict = None ):
+    options: dict = None,
+    geometry_options: dict = None):
 
     """Create a new instance of "send_geometry".
 
@@ -254,28 +294,35 @@ def send_geometry(
         A dictionary to show / hide button options. Defaults to show all.
 
         {
-            'add', = True or False
-            'delete', = True or False
-            'preview', = True or False
-            'clear', = True or False
+            'add' = True or False
+            'delete' = True or False
+            'preview' = True or False
+            'clear' = True or False
             'subscribe-preview' = True or False
         }
-    
+    geometry_options: dictionary or None
+        A dictionary to control translation of geometry from app to CAD plugin.
+        Defaults to using the CAD plugin document settings.
+
+        {
+            'units' = 'Meters' | 'Millimeters' | 'Feet' | 'Inches' | 'Centimeters',
+        }
     Returns
     -------
     """
 
-    send_geometry = _send_geometry( key=key, geometry=geometry, option=option, button_label=label, options_config = options)
+    send_geometry = _send_geometry(
+      component='send_geometry',
+      key=key,
+      geometry=geometry,
+      option=option,
+      button_label=label,
+      options_config=options,
+      geometry_options=geometry_options
+    )
 
     return send_geometry
 
-
-# send_hbjson
-parent_dir = os.path.dirname(os.path.abspath(__file__))
-build_dir = os.path.join(parent_dir, "./send_hbjson/frontend/build")
-_send_hbjson = _components.declare_component("send_hbjson", path=build_dir)
-
-
 def send_hbjson(key='foo', *, 
     hbjson={}, 
     option='preview',
@@ -311,6 +358,7 @@ def send_hbjson(key='foo', *,
     """
 
     send_hbjson = _send_hbjson(
+        component='send_hbjson',
         key=key,
         hbjson=hbjson,
         option=option,
@@ -320,18 +368,12 @@ def send_hbjson(key='foo', *,
 
     return send_hbjson
 
-
-# send_results
-parent_dir = os.path.dirname(os.path.abspath(__file__))
-build_dir = os.path.join(parent_dir, "./send_results/frontend/build")
-_send_results = _components.declare_component("send_results", path=build_dir)
-
-
 def send_results(key='foo', *, 
     results={}, 
     option='preview', 
     options=None, 
-    label=None ):
+    label=None,
+    geometry_options: dict = None):
     
     """Create a new instance of "send_results".
 
@@ -358,28 +400,29 @@ def send_results(key='foo', *,
             'clear', = True or False
             'subscribe-preview' = True or False
         }
-        
+    geometry_options: dictionary or None
+        A dictionary to control translation of geometry from app to CAD plugin.
+        Defaults to using the CAD plugin document settings.
+
+        {
+            'units' = 'Meters' | 'Millimeters' | 'Feet' | 'Inches' | 'Centimeters',
+        }
     Returns
     -------
     """
 
     send_results = _send_results(
+        component='send_results',
         key=key, 
         results=results, 
         option=option, 
         options_config=options, 
-        button_label=label
+        button_label=label,
+        geometry_options=geometry_options
     )
 
     return send_results
 
-
-# auth_user
-parent_dir = os.path.dirname(os.path.abspath(__file__))
-build_dir = os.path.join(parent_dir, "./auth_user/frontend/build")
-_auth_user = _components.declare_component("auth_user", path=build_dir)
-
-
 def auth_user(key='foo', api_client: ApiClient = None):
     """Create a new instance of "auth_user".
 
@@ -415,21 +458,16 @@ def auth_user(key='foo', api_client: ApiClient = None):
 
     client = api_client.__dict__
 
-    auth_user = _auth_user(key=key,
-                           access_token=client["_jwt_token"],
-                           api_key=client["_api_token"],
-                           base_path=client["_host"])
+    auth_user = _auth_user(
+      component='auth_user',
+      key=key,
+      access_token=client["_jwt_token"],
+      api_key=client["_api_token"],
+      base_path=client["_host"]
+    )
 
     return auth_user
 
-
-# select_account
-parent_dir = os.path.dirname(os.path.abspath(__file__))
-build_dir = os.path.join(parent_dir, "./select_account/frontend/build")
-_select_account = _components.declare_component(
-    "select_account", path=build_dir)
-
-
 def select_account(
     key='foo',
     api_client: ApiClient = None, *,
@@ -501,20 +539,83 @@ def select_account(
         kwargs = kwargs or {}
         register_callback(key, on_change, *args, **kwargs)
 
-    select_account = _select_account(key=key,
-                                     access_token=client["_jwt_token"],
-                                     api_key=client["_api_token"],
-                                     base_path=client["_host"])
+    select_account = _select_account(
+      component='select_account',
+      key=key,
+      access_token=client["_jwt_token"],
+      api_key=client["_api_token"],
+      base_path=client["_host"]
+    )
 
     return select_account
 
+def select_cloud_artifact(
+    key='foo',
+    api_client: ApiClient = None, *,
+    project_name: str,
+    project_owner: str,
+    study_id: str,
+    file_name_match: str = ".*",
+    on_change:  Callable = None,
+    args: Tuple = None,
+    kwargs: Dict = None,
+):
+    """Create a new instance of "select_cloud_artifact".
 
-# # select_project
-parent_dir = os.path.dirname(os.path.abspath(__file__))
-build_dir = os.path.join(parent_dir, "./select_project/frontend/build")
-_select_project = _components.declare_component(
-    "select_project", path=build_dir)
+    Parameters
+    ----------
+    key: str or None
+        An optional key that uniquely identifies this component. If this is
+        None, and the component's arguments are changed, the component will
+        be re-mounted in the Streamlit frontend and lose its current state.
+    api_client: ApiClient
+        ApiClient is a class returned by get_api_client(), part of the 
+        pollination_streamlit package.
+        ```
+        from pollination_streamlit.selectors import get_api_client
+        ...
+        api_client = get_api_client
+        ```
+    project_name: str
+        A project's unique name
+    project_owner: str
+        The username (user) or account_name (org) of a projects owner
+    file_name_match: str
+        A regular expression to match the file name, e.g. ".*(hbjson$)"
+    on_change: Callable or None
+        An optional on_change function that will be called when hbjson input
+        is changed.
+    args: Tuple or None
+        An optional tuple of positional arguments that will be passed to the
+        on_change function.
+    kwargs: dictionary or None
+        An optional dictionary of kwargs that will be passed to the on_change
+        function.
+    
+    Returns
+    -------
+    file: 
+    """
+    client = api_client.__dict__
 
+    if on_change is not None:
+        args = args or []
+        kwargs = kwargs or {}
+        register_callback(key, on_change, *args, **kwargs)
+
+    select_cloud_artifact = _select_cloud_artifact(
+      component='select_cloud_artifact',
+      key=key,
+      project_name=project_name,
+      project_owner=project_owner,
+      study_id=study_id,
+      file_name_match=file_name_match,
+      access_token=client["_jwt_token"],
+      api_key=client["_api_token"],
+      base_path=client["_host"],
+    )
+
+    return select_cloud_artifact
 
 def select_project(
     key='foo', 
@@ -609,22 +710,17 @@ def select_project(
     
     client = api_client.__dict__
 
-    select_project = _select_project(key=key,
-                                     project_owner=project_owner,
-                                     access_token=client["_jwt_token"],
-                                     api_key=client["_api_token"],
-                                     base_path=client["_host"])
+    select_project = _select_project(
+      component='select_project',
+      key=key,
+      project_owner=project_owner,
+      access_token=client["_jwt_token"],
+      api_key=client["_api_token"],
+      base_path=client["_host"]
+    )
 
     return select_project
 
-
-# select_recipe
-parent_dir = os.path.dirname(os.path.abspath(__file__))
-build_dir = os.path.join(parent_dir, "./select_recipe/frontend/build")
-_select_recipe = _components.declare_component(
-    "select_recipe", path=build_dir)
-
-
 def select_recipe(
     key='foo', 
     api_client: ApiClient = None, *, 
@@ -680,6 +776,7 @@ def select_recipe(
     client = api_client.__dict__
 
     select_recipe = _select_recipe(
+        component='select_recipe',
         key=key,
         project_name=project_name,
         project_owner=project_owner,
@@ -689,14 +786,6 @@ def select_recipe(
 
     return select_recipe
 
-
-# select_study
-parent_dir = os.path.dirname(os.path.abspath(__file__))
-build_dir = os.path.join(parent_dir, "./select_study/frontend/build")
-_select_study = _components.declare_component(
-    "select_study", path=build_dir)
-
-
 def select_study(
     key='foo', api_client: ApiClient = None, *,
     project_name=None,
@@ -750,6 +839,7 @@ def select_study(
     client = api_client.__dict__
 
     select_study = _select_study(
+        component='select_study',
         key=key,
         project_name=project_name,
         project_owner=project_owner,
@@ -759,14 +849,6 @@ def select_study(
 
     return select_study
 
-
-# select_run
-parent_dir = os.path.dirname(os.path.abspath(__file__))
-build_dir = os.path.join(parent_dir, "./select_run/frontend/build")
-_select_run = _components.declare_component(
-    "select_run", path=build_dir)
-
-
 def select_run(
     key='foo', api_client: ApiClient = None, *,
     project_name=None,
@@ -822,6 +904,7 @@ def select_run(
     client = api_client.__dict__
 
     select_run = _select_run(
+        component='select_run',
         key=key,
         project_name=project_name,
         project_owner=project_owner,
@@ -832,15 +915,6 @@ def select_run(
 
     return select_run
 
-
-
-# select_run
-parent_dir = os.path.dirname(os.path.abspath(__file__))
-build_dir = os.path.join(parent_dir, "./create_study/frontend/build")
-_create_study = _components.declare_component(
-    "create_study", path=build_dir)
-
-
 def create_study(
     key='foo', api_client: ApiClient = None, *,
     on_change:  Callable = None,
@@ -875,10 +949,6 @@ def create_study(
         
     Returns
     -------
-    dict
-        A dictionary with the sturcture described here:
-
-            https://api.pollination.cloud/docs#/Runs/list_runs
     """
 
     if on_change is not None:
@@ -889,9 +959,191 @@ def create_study(
     client = api_client.__dict__
 
     create_study = _create_study(
+        component='create_study',
         key=key,
         access_token=client["_jwt_token"],
         api_key=client["_api_token"],
+        base_path=client["_host"]
+    )
+
+    return create_study
+
+def recipe_inputs_form(
+    key='foo', api_client: ApiClient = None, *,
+    project_name: str = None,
+    project_owner: str = None,
+    default_inputs: Dict = None,
+    recipe: Dict = None,
+    on_change:  Callable = None,
+    args: Tuple = None,
+    kwargs: Dict = None
+):
+    """Create a new instance of "select_run".
+
+    Parameters
+    ----------
+    key: str or None
+        An optional key that uniquely identifies this component. If this is
+        None, and the component's arguments are changed, the component will
+        be re-mounted in the Streamlit frontend and lose its current state.
+    api_client: ApiClient
+        ApiClient is a class returned by get_api_client(), part of the 
+        pollination_streamlit package.
+        ```
+        from pollination_streamlit.selectors import get_api_client
+        ...
+        api_client = get_api_client
+        ```
+    project_name: str
+        Unique name representing a project
+    project_owner: str
+        Unique name representing the project's owner
+    default_inputs: Dict
+        A dictionary with the structure
+        
+        {
+            [input_name: string] : {
+                value: string,
+                hidden: boolean
+            }
+        }
+
+        The hidden field will be optional, but hasn't been fully implemented yet.
+    recipe: Dict
+        Dictionary representing a pollination recipe, use select_recipe
+    on_change: Callable or None
+        An optional on_change function that will be called when hbjson input
+        is changed.
+    args: Tuple or None
+        An optional tuple of positional arguments that will be passed to the
+        on_change function.
+    kwargs: dictionary or None
+        An optional dictionary of kwargs that will be passed to the on_change
+        function.
+        
+    Returns
+    -------
+    
+    """
+
+    if on_change is not None:
+        args = args or []
+        kwargs = kwargs or {}
+        register_callback(key, on_change, *args, **kwargs)
+
+    client = api_client.__dict__
+
+    recipe_inputs_form = _recipe_inputs_form(
+        component='recipe_inputs_form',
+        key=key,
+        access_token=client["_jwt_token"],
+        api_key=client["_api_token"],
+        base_path=client["_host"],
+        project_owner=project_owner,
+        project_name=project_name,
+        default_inputs=default_inputs,
+        recipe=recipe)
+
+    return recipe_inputs_form
+
+def study_card(
+    key='foo', api_client: ApiClient = None, *,
+    project_name=None,
+    project_owner=None,
+    study=None,
+    run_list=None,
+):
+    """Create a new instance of "select_run".
+
+    Parameters
+    ----------
+    key: str or None
+        An optional key that uniquely identifies this component. If this is
+        None, and the component's arguments are changed, the component will
+        be re-mounted in the Streamlit frontend and lose its current state.
+    api_client: ApiClient
+        ApiClient is a class returned by get_api_client(), part of the 
+        pollination_streamlit package.
+        ```
+        from pollination_streamlit.selectors import get_api_client
+        ...
+        api_client = get_api_client
+        ```
+    project_name: string
+        The projects unique name
+    project_owner: string
+        The project owner's unique name
+    study: dict
+        A dictionary that represents a Study, or Job as it's called in the 
+        pollination-sdk. Retreive a study object using the select_study component.
+    run_list: boolean
+        Toggle the runs list at the bottom of the card
+        
+    Returns
+    -------
+    """
+
+    client = api_client.__dict__
+
+    study_card = _study_card(
+        component='study_card',
+        key=key,
+        project_name=project_name,
+        project_owner=project_owner,
+        study=study,
+        run_list=run_list,
+        access_token=client["_jwt_token"],
+        api_key=client["_api_token"],
         base_path=client["_host"])
 
-    return create_study
+    return study_card
+
+def run_card(
+    key='foo', api_client: ApiClient = None, *,
+    project_name=None,
+    project_owner=None,
+    job_id=None,
+    run=None,
+):
+    """Create a new instance of "select_run".
+
+    Parameters
+    ----------
+    key: str or None
+        An optional key that uniquely identifies this component. If this is
+        None, and the component's arguments are changed, the component will
+        be re-mounted in the Streamlit frontend and lose its current state.
+    api_client: ApiClient
+        ApiClient is a class returned by get_api_client(), part of the 
+        pollination_streamlit package.
+        ```
+        from pollination_streamlit.selectors import get_api_client
+        ...
+        api_client = get_api_client
+        ```
+    project_name: string
+        The projects unique name
+    project_owner: string
+        The project owner's unique name
+    run: dict
+        A dictionary representing a CloudRun object. Retrieve this object using the 
+        select_run component.
+        
+    Returns
+    -------
+    """
+
+    client = api_client.__dict__
+
+    run_card = _run_card(
+        component='run_card',
+        key=key,
+        project_name=project_name,
+        project_owner=project_owner,
+        job_id=job_id,
+        run=run,
+        access_token=client["_jwt_token"],
+        api_key=client["_api_token"],
+        base_path=client["_host"])
+
+    return run_card
